<?php

namespace Frontend\Modules\Blog\Widgets;

/*
 * This file is part of Fork CMS.
 *
 * For the full copyright and license information, please view the license
 * file that was distributed with this source code.
 */

use Frontend\Core\Engine\Base\Widget as FrontendBaseWidget;
use Frontend\Core\Engine\Model as FrontendModel;
use Frontend\Core\Engine\Navigation as FrontendNavigation;
use Frontend\Modules\Blog\Engine\Model as FrontendBlogModel;

/**
 * This is a widget with recent blog-articles
 *
 * @author Tijs Verkoyen <tijs@sumocoders.be>
 */
class RecentArticlesList extends FrontendBaseWidget
{
    /**
     * Execute the extra
     */
    public function execute()
    {
        parent::execute();
        $this->loadTemplate();
        $this->parse();
    }

    /**
     * Parse
     */
    private function parse()
    {
        // get RSS-link
        $rssLink = FrontendModel::getModuleSetting('Blog', 'feedburner_url_' . FRONTEND_LANGUAGE);
        if ($rssLink == '') {
            $rssLink = FrontendNavigation::getURLForBlock('Blog', 'Rss');
        }

        // add RSS-feed into the metaCustom
        $this->header->addLink(
            array(
                 'rel' => 'alternate',
                 'type' => 'application/rss+xml',
                 'title' => FrontendModel::getModuleSetting('Blog', 'rss_title_' . FRONTEND_LANGUAGE),
                 'href' => $rssLink
            ),
            true
        );

        // assign comments
        $this->tpl->assign(
            'widgetBlogRecentArticlesList',
            FrontendBlogModel::getAll(FrontendModel::getModuleSetting('Blog', 'recent_articles_list_num_items', 5))
        );
        $this->tpl->assign('widgetBlogRecentArticlesFullRssLink', $rssLink);
    }
}
